@@ -31,12 +31,10 @@ const FAIL_FORMAT: &str = "Failed to format OS Error";
 use core::fmt;
 use core::marker::PhantomData;
 
-mod buf;
 ///Static string used to store error message.
 ///
 ///Limited to 128 characters, truncates on overflow.
-pub type Str = buf::StrBuf::<[u8; 128]>;
-pub use buf::StrBuf;
+pub type Str = str_buf::StrBuf::<[u8; 128]>;
 
 mod posix;
 pub use posix::PosixCategory;
@@ -118,7 +116,7 @@ impl ErrorCode<PosixCategory> {
     ///
     ///Under POSIX, it means either `EWOULDBLOCK` or `EAGAIN`, in some cases it can be the same
     ///error code.
-    pub fn is_would_block(self) -> bool {
+    pub const fn is_would_block(self) -> bool {
         posix::is_would_block(self.code)
     }
 }
@@ -137,7 +135,7 @@ impl ErrorCode<SystemCategory> {
     ///Under POSIX, it means either `EWOULDBLOCK` or `EAGAIN`, in some cases it can be the same
     ///error code.
     ///In case of Windows, it is also `WSAEWOULDBLOCK`
-    pub fn is_would_block(self) -> bool {
+    pub const fn is_would_block(self) -> bool {
         #[cfg(windows)]
         {
             if self.code == 10035 {
